==> 11.5.0+6.tar.gz: lib/XfXWidgets/XfxSchedaTapped.dart <==
part of xwidgetbase;

class XfxSchedaTabbed extends StatefulWidget {
  XfxSchedaTabbed({
    Key? key,
    this.title = "",
    this.backGroundColor,
    this.title_Color,
    this.title_Visible = true,
    this.children,
    this.numberOfTabs,
    required this.xTabs,
    this.bottomBar_Visible = true,
    this.isScrollableTabs = false,
    this.bottomBar_OnTap,
    this.bottomBar_CurrentIdx,
    this.tabs_BackGroundColor,
    this.margin_Horizontal,
    this.title_Style,
    required this.bottomBar_Children,
    this.sch_Decoration,
    this.borderVisible,
  }) : super(key: key);
  final String title;
  final bool title_Visible;
  final Color? title_Color;
  final List<Widget>? children;
  final bool? borderVisible;
  final Color? backGroundColor;
  final int? numberOfTabs;
  final bool? bottomBar_Visible;
  late List<XTabItem> xTabs;
  final bool? isScrollableTabs;
  final Decoration? sch_Decoration;
  final int? bottomBar_CurrentIdx;
  final Function(int)? bottomBar_OnTap;
  final double? margin_Horizontal;
  List<BottomNavigationBarItem> bottomBar_Children;
  final Color? tabs_BackGroundColor;
  final TextStyle? title_Style;
  @override
  XfxSchedaTabbedState createState() => XfxSchedaTabbedState();

  static XfxScheda tabViewerPagesSch(String titleScheda, Widget? childOfSchedaTabViewer, List<BottomNavigationBarItem> childrenOfBottomBar) {
    return XfxScheda(bottomBar_Visible: false, title: titleScheda, child: childOfSchedaTabViewer, bottomBar_Children: childrenOfBottomBar);
  }

  static Widget templateSchedaViewerSch(
    String subTitle,
    String descr,
  ) {
    return Column(
      children: [
        SizedBox(height: 5),
        XContainerWithLabel(
          subTitle,
          color: XColors.backgroundDark,
          alignmentContainer: Alignment.centerLeft,
          textStyle: XStyles.xStyTextForLabel(),
        ),
        SizedBox(height: 5),
        XContainerWithLabel(
          descr,
          color: XColors.backgroundDark,
          alignmentContainer: Alignment.centerLeft,
          textAlignment: TextAlign.left,
          textStyle: XStyles.xStyTextForLabel(),
        ),
      ],
    );
  }
}

class XfxSchedaTabbedState extends State<XfxSchedaTabbed> with SingleTickerProviderStateMixin {
  late TabController tabController;

  @override
  void initState() {
    super.initState();
    tabController = TabController(length: widget.xTabs.length, vsync: this, animationDuration: Duration.zero);
    var _controllerIsValid = tabController.animation != null;
    if (_controllerIsValid) {
      tabController.addListener(() {
        setState(() {});
      });
      tabController.animation!.addListener(() {
        setState(() {});
      });
    }
  }

  tabPagesSch(
    IconData? icon,
    String? label,
    XTabItem? item, {
    TextStyle? labelStyle_ALL,
    Color? labelColor_ALL,
    Color? labelColor_Active,
    Color? labelColor_Disabled,
    Color? iconsColor_ALL,
    Color? iconsColor_Active,
    Color? iconsColor_Disabled,
    Color? color_backGroundTab_Activate,
    Color? color_backGroundTab,
  }) {
    Color getTabItem_IconColor(XTabItem item, int idx) {
      if (tabController.index == item.idx) {
        return item.iconColor_Active ?? iconsColor_Active ?? iconsColor_ALL ?? XColors.foregroundLight;
      } else {
        return item.iconColor_Disabled ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    Color getTabItem_LabelColor(XTabItem item, int idx) {
      if (tabController.index == item.idx) {
        return item.labelColor_Active ?? labelColor_Active ?? iconsColor_Active ?? labelColor_ALL ?? iconsColor_ALL ?? XColors.foregroundLight;
      } else {
        return item.labelColor_Disabled ?? labelColor_Disabled ?? labelColor_ALL ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    return Container(
        color: getTabItem_BackgroundColor(item!, tabController.index),
        child: Tab(
            height: 40,
            iconMargin: EdgeInsets.only(bottom: 2),
            icon: icon != null ? Icon(icon, color: iconsColor_ALL ?? getTabItem_IconColor(item, tabController.index)) : null,
            child: Row(children: [
              widget.xTabs.length > 3
                  ? Container(
                      padding: EdgeInsets.symmetric(horizontal: 10),
                      child: Text(
                        label ?? "",
                        textAlign: TextAlign.center,
                        style: labelStyle_ALL ?? XStyles.xStyTextForDescr(getTabItem_LabelColor(item, tabController.index)),
                      ))
                  : Expanded(
                      child: Container(
                          padding: EdgeInsets.symmetric(horizontal: 10),
                          child: Text(
                            label ?? "",
                            textAlign: TextAlign.center,
                            style: labelStyle_ALL ?? XStyles.xStyTextForDescr(getTabItem_LabelColor(item, tabController.index)),
                          )))
            ])));
  }

  Color getTabItem_BackgroundColor(XTabItem item, int idx) {
    if (tabController.index == item.idx) {
      return item.color_backGroundTab_Activate ?? Colors.grey[900]!;
    } else {
      return item.color_backGroundTab ?? Colors.grey[900]!;
    }
  }

  @override
  Widget build(BuildContext context) {
    return
        // DefaultTabController(
        //     length: widget.numberOfTabs!,
        //     child:
        Scaffold(
            backgroundColor: widget.backGroundColor,
            body: Container(
                decoration: widget.sch_Decoration,
                margin: EdgeInsets.symmetric(horizontal: widget.margin_Horizontal ?? 15),
                child: Column(children: [
                  widget.title_Visible == true ? SizedBox(height: 10) : SizedBox(height: 0),
                  widget.title_Visible == true
                      ? Row(
                          children: [
                            Expanded(child: XContainerWithLabel(widget.title, height: 30, color: XColors.backGroundTitleContainerForScheda_MAIN, textStyle: widget.title_Style ?? XStyles.xStyTextForTextBase(widget.title_Color ?? Colors.white))),
                          ],
                        )
                      : Container(),
                  widget.title_Visible == true ? SizedBox(height: 3) : SizedBox(height: 0),
                  TabBar(
                    controller: tabController,
                    indicator: BoxDecoration(color: widget.tabs_BackGroundColor),
                    isScrollable: widget.xTabs.length > 3 ? true : widget.isScrollableTabs!,
                    indicatorPadding: EdgeInsets.all(0),
                    labelPadding: EdgeInsets.all(0),
                    padding: EdgeInsets.all(0),
                    tabs: widget.xTabs
                        .map((x) => tabPagesSch(
                              x.icon,
                              x.caption,
                              x,
                              iconsColor_Active: x.iconColor_Active,
                              iconsColor_Disabled: x.iconColor_Disabled,
                              labelColor_Active: x.labelColor_Active,
                              labelColor_Disabled: x.labelColor_Disabled,
                            ) as Widget)
                        .toList(),
                    onTap: (idx) {
                      // setState(() {
                      //   //   widget.tabController!.index = idx;
                      // });
                      FocusScopeNode currentFocus = FocusScope.of(context);
                      if (!currentFocus.hasPrimaryFocus && currentFocus.focusedChild != null) {
                        FocusManager.instance.primaryFocus?.unfocus();
                      }
                    },
                  ),
                  Expanded(
                      child: Container(
                          decoration: (widget.borderVisible ?? false) //
                              ? BoxDecoration(color: XColors.backgroundDark, border: Border.all(color: widget.tabs_BackGroundColor ?? Colors.transparent, width: 2)) //
                              : null,
                          child: GestureDetector(
                              // onHorizontalDragEnd: (details) {
                              //   setState(() {});
                              // },
                              child: TabBarView(
                            children: widget.children!,
                            controller: tabController,
                          )))),
                  SizedBox(height: 5),
                ])),
            bottomNavigationBar: widget.bottomBar_Visible == true
                ? BottomNavigationBar(
                    type: BottomNavigationBarType.fixed,
                    currentIndex: widget.bottomBar_CurrentIdx ?? 0,
                    onTap: widget.bottomBar_OnTap,
                    enableFeedback: true,
                    showUnselectedLabels: true,
                    selectedItemColor: Colors.blue[700],
                    selectedFontSize: 15,
                    selectedLabelStyle: XStyles.xStyleText(),
                    backgroundColor: Colors.grey[900],
                    unselectedItemColor: XColors.foregroundLight,
                    unselectedFontSize: 10,
                    unselectedLabelStyle: XStyles.xStyleText(),
                    iconSize: 20,
                    items: widget.bottomBar_Children,
                  )
                : Container(height: 1));
  }

  //gestisco il controller, allineandolo alla qta di tabs
  @override
  void didUpdateWidget(XfxSchedaTabbed oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.xTabs.length != widget.xTabs.length) {
      // If the length is shortened while the last tab is selected, we should
      // automatically update the index of the controller to be the new last tab.
      int newIndex = 0;
      // int previousIndex = tabController.previousIndex;
      if (tabController.index >= widget.xTabs.length) {
        newIndex = max(0, widget.xTabs.length - 1);
        // previousIndex = tabController.index;
      }
      tabController = TabController(length: widget.xTabs.length - 1, vsync: this, animationDuration: tabController.animationDuration, initialIndex: newIndex);
    }

    // if (oldWidget.animationDuration != widget.animationDuration) {
    //   tabController = _copyWith(
    //     length:  widget.xTabs.length,
    //     // animationDuration: widget.animationDuration,
    //     index: tabController.index,
    //     previousIndex: tabController.previousIndex,
    //   );
    // }
  }
}

==> 11.5.9+6.tar.gz: lib/XfXWidgets/XfxSchedaTapped.dart <==
part of xwidgetbase;

class XfxSchedaTabbed extends StatefulWidget {
  XfxSchedaTabbed({
    Key? key,
    this.title = "",
    this.backGroundColor,
    this.title_Color,
    this.title_Visible = true,
    this.children,
    this.numberOfTabs,
    required this.xTabs,
    this.bottomBar_Visible = true,
    this.isScrollableTabs = false,
    this.bottomBar_OnTap,
    this.bottomBar_CurrentIdx,
    this.tabs_BackGroundColor,
    this.margin_Horizontal,
    this.title_Style,
    required this.bottomBar_Children,
    this.sch_Decoration,
    this.borderVisible,
    this.currentTabIdx = 0,
  }) : super(key: key);
  final String title;
  final bool title_Visible;
  final Color? title_Color;
  final List<Widget>? children;
  final bool? borderVisible;
  final Color? backGroundColor;
  final int? numberOfTabs;
  final bool? bottomBar_Visible;
  late List<XTabItem> xTabs;
  final bool? isScrollableTabs;
  final Decoration? sch_Decoration;
  final int? bottomBar_CurrentIdx;
  final Function(int)? bottomBar_OnTap;
  final double? margin_Horizontal;
  List<BottomNavigationBarItem> bottomBar_Children;
  final Color? tabs_BackGroundColor;
  final TextStyle? title_Style;
  int currentTabIdx;
  @override
  XfxSchedaTabbedState createState() => XfxSchedaTabbedState();

  static XfxScheda tabViewerPagesSch(String titleScheda, Widget? childOfSchedaTabViewer, List<BottomNavigationBarItem> childrenOfBottomBar) {
    return XfxScheda(bottomBar_Visible: false, title: titleScheda, child: childOfSchedaTabViewer, bottomBar_Children: childrenOfBottomBar);
  }

  static Widget templateSchedaViewerSch(
    String subTitle,
    String descr,
  ) {
    return Column(
      children: [
        SizedBox(height: 5),
        XContainerWithLabel(
          subTitle,
          color: XColors.backgroundDark,
          alignmentContainer: Alignment.centerLeft,
          textStyle: XStyles.xStyTextForLabel(),
        ),
        SizedBox(height: 5),
        XContainerWithLabel(
          descr,
          color: XColors.backgroundDark,
          alignmentContainer: Alignment.centerLeft,
          textAlignment: TextAlign.left,
          textStyle: XStyles.xStyTextForLabel(),
        ),
      ],
    );
  }
}

class XfxSchedaTabbedState extends State<XfxSchedaTabbed> with SingleTickerProviderStateMixin {
  late TabController tabController;

  @override
  void initState() {
    super.initState();
    tabController = TabController(length: widget.xTabs.length, vsync: this, initialIndex: widget.currentTabIdx, animationDuration: Duration.zero);
    var _controllerIsValid = tabController.animation != null;
    if (_controllerIsValid) {
      tabController.addListener(() {
        setState(() {
          widget.currentTabIdx = tabController.index;
        });
      });
      tabController.animation!.addListener(() {
        setState(() {
          widget.currentTabIdx = tabController.index;
        });
      });
    }
  }

  tabPagesSch(
    IconData? icon,
    String? label,
    XTabItem? item, {
    TextStyle? labelStyle_ALL,
    Color? labelColor_ALL,
    Color? labelColor_Active,
    Color? labelColor_Disabled,
    Color? iconsColor_ALL,
    Color? iconsColor_Active,
    Color? iconsColor_Disabled,
    Color? color_backGroundTab_Activate,
    Color? color_backGroundTab,
  }) {
    Color getTabItem_IconColor(XTabItem item, int idx) {
      if (tabController.index == item.idx) {
        return item.iconColor_Active ?? iconsColor_Active ?? iconsColor_ALL ?? XColors.foregroundLight;
      } else {
        return item.iconColor_Disabled ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    Color getTabItem_LabelColor(XTabItem item, int idx) {
      if (tabController.index == item.idx) {
        return item.labelColor_Active ?? labelColor_Active ?? iconsColor_Active ?? labelColor_ALL ?? iconsColor_ALL ?? XColors.foregroundLight;
      } else {
        return item.labelColor_Disabled ?? labelColor_Disabled ?? labelColor_ALL ?? iconsColor_Disabled ?? iconsColor_ALL ?? XColors.foregroundLight;
      }
    }

    return Container(
        color: getTabItem_BackgroundColor(item!, tabController.index),
        child: Tab(
            height: 40,
            iconMargin: EdgeInsets.only(bottom: 2),
            icon: icon != null ? Icon(icon, color: iconsColor_ALL ?? getTabItem_IconColor(item, tabController.index)) : null,
            child: Row(children: [
              widget.xTabs.length > 3
                  ? Container(
                      padding: EdgeInsets.symmetric(horizontal: 10),
                      child: Text(
                        label ?? "",
                        textAlign: TextAlign.center,
                        style: labelStyle_ALL ?? XStyles.xStyTextForDescr(getTabItem_LabelColor(item, tabController.index)),
                      ))
                  : Expanded(
                      child: Container(
                          padding: EdgeInsets.symmetric(horizontal: 10),
                          child: Text(
                            label ?? "",
                            textAlign: TextAlign.center,
                            style: labelStyle_ALL ?? XStyles.xStyTextForDescr(getTabItem_LabelColor(item, tabController.index)),
                          )))
            ])));
  }

  Color getTabItem_BackgroundColor(XTabItem item, int idx) {
    if (tabController.index == item.idx) {
      return item.color_backGroundTab_Activate ?? Colors.grey[900]!;
    } else {
      return item.color_backGroundTab ?? Colors.grey[900]!;
    }
  }

  @override
  Widget build(BuildContext context) {
    return
        // DefaultTabController(
        //     length: widget.numberOfTabs!,
        //     child:
        Scaffold(
            backgroundColor: widget.backGroundColor,
            body: Container(
                decoration: widget.sch_Decoration,
                margin: EdgeInsets.symmetric(horizontal: widget.margin_Horizontal ?? 15),
                child: Column(children: [
                  widget.title_Visible == true ? SizedBox(height: 10) : SizedBox(height: 0),
                  widget.title_Visible == true
                      ? Row(
                          children: [
                            Expanded(child: XContainerWithLabel(widget.title, height: 30, color: XColors.backGroundTitleContainerForScheda_MAIN, textStyle: widget.title_Style ?? XStyles.xStyTextForTextBase(widget.title_Color ?? Colors.white))),
                          ],
                        )
                      : Container(),
                  widget.title_Visible == true ? SizedBox(height: 3) : SizedBox(height: 0),
                  TabBar(
                    controller: tabController,
                    indicator: BoxDecoration(color: widget.tabs_BackGroundColor),
                    isScrollable: widget.xTabs.length > 3 ? true : widget.isScrollableTabs!,
                    indicatorPadding: EdgeInsets.all(0),
                    labelPadding: EdgeInsets.all(0),
                    padding: EdgeInsets.all(0),
                    tabs: widget.xTabs
                        .map((x) => tabPagesSch(
                              x.icon,
                              x.caption,
                              x,
                              iconsColor_Active: x.iconColor_Active,
                              iconsColor_Disabled: x.iconColor_Disabled,
                              labelColor_Active: x.labelColor_Active,
                              labelColor_Disabled: x.labelColor_Disabled,
                            ) as Widget)
                        .toList(),
                    onTap: (idx) {
                      // setState(() {
                      //   //   widget.tabController!.index = idx;
                      // });
                      FocusScopeNode currentFocus = FocusScope.of(context);
                      if (!currentFocus.hasPrimaryFocus && currentFocus.focusedChild != null) {
                        FocusManager.instance.primaryFocus?.unfocus();
                      }
                    },
                  ),
                  Expanded(
                      child: Container(
                          decoration: (widget.borderVisible ?? false) //
                              ? BoxDecoration(color: XColors.backgroundDark, border: Border.all(color: widget.tabs_BackGroundColor ?? Colors.transparent, width: 2)) //
                              : null,
                          child: GestureDetector(
                              // onHorizontalDragEnd: (details) {
                              //   setState(() {});
                              // },
                              child: TabBarView(
                            children: widget.children!,
                            controller: tabController,
                          )))),
                  SizedBox(height: 5),
                ])),
            bottomNavigationBar: widget.bottomBar_Visible == true
                ? BottomNavigationBar(
                    type: BottomNavigationBarType.fixed,
                    currentIndex: widget.bottomBar_CurrentIdx ?? 0,
                    onTap: widget.bottomBar_OnTap,
                    enableFeedback: true,
                    showUnselectedLabels: true,
                    selectedItemColor: Colors.blue[700],
                    selectedFontSize: 15,
                    selectedLabelStyle: XStyles.xStyleText(),
                    backgroundColor: Colors.grey[900],
                    unselectedItemColor: XColors.foregroundLight,
                    unselectedFontSize: 10,
                    unselectedLabelStyle: XStyles.xStyleText(),
                    iconSize: 20,
                    items: widget.bottomBar_Children,
                  )
                : Container(height: 1));
  }

  //gestisco il controller, allineandolo alla qta di tabs
  @override
  void didUpdateWidget(XfxSchedaTabbed oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.xTabs.length != widget.xTabs.length) {
      // If the length is shortened while the last tab is selected, we should
      // automatically update the index of the controller to be the new last tab.
      int newIndex = 0;
      // int previousIndex = tabController.previousIndex;
      if (tabController.index >= widget.xTabs.length) {
        newIndex = max(0, widget.xTabs.length - 1);
        // previousIndex = tabController.index;
      }
      tabController = TabController(length: widget.xTabs.length - 1, vsync: this, animationDuration: tabController.animationDuration, initialIndex: newIndex);
    }

    // if (oldWidget.animationDuration != widget.animationDuration) {
    //   tabController = _copyWith(
    //     length:  widget.xTabs.length,
    //     // animationDuration: widget.animationDuration,
    //     index: tabController.index,
    //     previousIndex: tabController.previousIndex,
    //   );
    // }
  }
}
